SpeechResultModel class

SpeechResultModel

Represents a speech recognition result with the recognized text and a flag indicating whether this is a final result or partial.

Example:

final result = SpeechResultModel('Hello world', true);
print(result.text); // 'Hello world'
print(result.isFinal); // true

Constructors

SpeechResultModel(String text, bool isFinal)
Creates a new speech result model
const
SpeechResultModel.final_(String text)
Creates a final result
factory
SpeechResultModel.partial(String text)
Creates a partial result
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
isFinal bool
Whether this is a final result (true) or partial (false)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String
The recognized text from speech input
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override