FiftySpeechEnginePlatform class abstract

The interface that implementations of fifty_speech_engine must implement.

Platform implementations should extend this class rather than implement it as FiftySpeechEnginePlatform does not consider newly added methods to be breaking changes. Extending this class (using extends) ensures that the subclass will get the default implementation, while platform implementations that implements this interface will be broken by newly added methods.

Inheritance
  • Object
  • PlatformInterface
  • FiftySpeechEnginePlatform
Implementers

Constructors

FiftySpeechEnginePlatform()
Constructs a FiftySpeechEnginePlatform.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getPlatformVersion() Future<String?>
Returns the platform version string.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance FiftySpeechEnginePlatform
The default instance of FiftySpeechEnginePlatform to use.
getter/setter pair